@@ -24,6 +24,7 @@ TS_NAME_FMT = "{expt:s}-{loc:s}~{res:s}-{step:s}"
 FULLRES_CONSTANTS = {"original", "orig", "fullres"}
 IMAGE_TYPE_CONSTANTS = {"raw", "jpg"}
 RAW_FORMATS = {"cr2", "nef", "tif", "tiff"}
+DATE_NOW_CONSTANTS = {"now", "current"}
 CLI_OPTS = """
 USAGE:
     exif2timestream.py [-t PROCESSES -1 -d -l LOGDIR] -c CAM_CONFIG_CSV
@@ -109,6 +110,8 @@ def validate_camera(camera):
         if isinstance(x, struct_time):
             return x
         else:
+            if x.lower() in DATE_NOW_CONSTANTS:
+                return NOW
             try:
                 return strptime(x, "%Y_%m_%d")
             except:
@@ -337,7 +340,7 @@ def _dont_clobber(fn, mode="append"):
     if path.exists(fn):
         # Deal with SkipImage or StopIteration exceptions
         if isinstance(mode, StopIteration):
-            LOG.debug("Path '{0}' exists, raising an Exception".format(fn))
+            LOG.debug("Path '{0}' exists, raising StopIteration".format(fn))
             raise mode
         # Ditto, but if we pass them uninstantiated
         elif isclass(mode) and issubclass(mode, StopIteration):
@@ -371,10 +374,13 @@ def process_image(args):
     image_date = get_file_date(image, camera[FIELDS["interval"]] * 60)
     if image_date < camera[FIELDS["expt_start"]] or \
             image_date > camera[FIELDS["expt_end"]]:
+        LOG.debug("Skipping {}. Outside of date range {!s} to {!s}".format(
+            image, camera[FIELDS["expt_start"]], camera[FIELDS["expt_end"]]))
         return  # Don't raise SkipImage as it isn't caught
 
     # archive a backup before we fuck anything up
     if camera[FIELDS["method"]] == "archive":
+        LOG.debug("Will archive {}".format(image))
         ts_name = make_timestream_name(camera, res="fullres")
         archive_image = path.join(
             camera[FIELDS["archive_dest"]],
@@ -390,8 +396,10 @@ def process_image(args):
             except OSError as exc:
                 if not path.exists(archive_dir):
                     raise exc
+            LOG.debug("Made archive dir {}".format(archive_dir))
         archive_image = _dont_clobber(archive_image)
         shutil.copy2(image, archive_image)
+        LOG.debug("Copied {} to {}".format(image, archive_image))
     # TODO: BUG: this won't work if images aren't in chronological order. Which
     # they never will be.
     # if last_date == image_date:
@@ -407,7 +415,9 @@ def process_image(args):
     try:
         # deal with original image (move/copy etc)
         timestreamise_image(image, camera, subsec=subsec, step=step)
+        LOG.debug("Successfully timestreamed {}".format(image))
     except SkipImage:
+        LOG.debug("Failed to timestream {} (got SkipImage)".format(image))
         if camera[FIELDS["method"]] == "archive":
             # we have changed this so that all images are moved to the archive
             pass
@@ -419,6 +429,7 @@ def process_image(args):
             os.unlink(image)
         except OSError as e:
             LOG.error("Could not delete '{0}'".format(image))
+        LOG.debug("Deleted {}".format(image))
 
 
 def get_local_path(this_path):
@@ -505,7 +516,7 @@ def setup_logs(opts):
         exit()
     # we want logging for the real main loop
     fmt = logging.Formatter(
-        '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+        '%(asctime)s - %(name)s.%(funcName)s - %(levelname)s - %(message)s')
     ch = logging.StreamHandler()
     ch.setLevel(logging.ERROR)
     ch.setFormatter(fmt)
@@ -553,10 +564,19 @@ def main(opts):
             n_images += n_cam_images
             last_date = None
             subsec = 0
+            count = 0
+            if n_cam_images < 100:
+                each = 10
+            else:
+                each = 50
             # TODO: sort out the whole subsecond clusterfuck
             if "-1" in opts and opts["-1"]:
-                LOG.info("using 1 process (What is this? Fucking 1990?)")
+                LOG.info("Using 1 process (What is this? Fucking 1990?)")
                 for image in images:
+                    count += 1
+                    if count % each == 0:
+                        print("Processed {: 5d} Images".format(count),
+                              end='\r')
                     process_image((image, camera, ext))
             else:
                 from multiprocessing import Pool, cpu_count
@@ -571,11 +591,6 @@ def main(opts):
                 # set the function's camera-wide arguments
                 args = zip(images, cycle([camera]), cycle([ext]))
                 pool = Pool(threads)
-                if n_cam_images < 100:
-                    each = 10
-                else:
-                    each = 50
-                count = 0
                 for _ in pool.imap(process_image, args):
                     count += 1
                     if count % each == 0:
@@ -583,7 +598,7 @@ def main(opts):
                               end='\r')
                 pool.close()
                 pool.join()
-        print("\n")
+            print("Processed {: 5d} Images".format(count))
     secs_taken = time() - start_time
     print("\nProcessed a total of {0} images in {1:.2f} seconds".format(
         n_images, secs_taken))
